@@ -83,8 +83,8 @@ class MintBackup:
 
         # set up exclusions page
         self.iconTheme = Gtk.IconTheme.get_default()
-        self.dir_icon = self.iconTheme.load_icon("folder-symbolic", 16, 0)
-        self.file_icon = self.iconTheme.load_icon("folder-documents-symbolic", 16, 0)
+        self.dir_icon = self.iconTheme.load_icon("xsi-folder-symbolic", 16, 0)
+        self.file_icon = self.iconTheme.load_icon("xsi-folder-documents-symbolic", 16, 0)
         treeview = self.builder.get_object("treeview_excludes")
         renderer = Gtk.CellRendererPixbuf()
         column = Gtk.TreeViewColumn("", renderer)
@@ -135,6 +135,7 @@ class MintBackup:
                     self.includes_model.append([item[len(self.home_directory) + 1:], self.file_icon, item])
         self.builder.get_object("button_include_hidden_files").connect("clicked", self.add_item_to_treeview, treeview, self.file_icon, Gtk.FileChooserAction.OPEN, True)
         self.builder.get_object("button_include_hidden_dirs").connect("clicked", self.add_item_to_treeview, treeview, self.dir_icon, Gtk.FileChooserAction.SELECT_FOLDER, True)
+        self.builder.get_object("button_include_all_hidden").connect("clicked", self.add_all_hidden_to_treeview, treeview)
         self.builder.get_object("button_remove_include").connect("clicked", self.remove_item_from_treeview, treeview)
 
         # Errors treeview for backup
@@ -208,12 +209,12 @@ class MintBackup:
         accel_group = Gtk.AccelGroup()
         self.main_window.add_accel_group(accel_group)
         menu = self.builder.get_object("main_menu")
-        item = Gtk.ImageMenuItem(label=_("About"), image=Gtk.Image(icon_name="help-about-symbolic", icon_size=Gtk.IconSize.MENU))
+        item = Gtk.ImageMenuItem(label=_("About"), image=Gtk.Image(icon_name="xsi-help-about-symbolic", icon_size=Gtk.IconSize.MENU))
         item.connect("activate", self.open_about)
         key, mod = Gtk.accelerator_parse("F1")
         item.add_accelerator("activate", accel_group, key, mod, Gtk.AccelFlags.VISIBLE)
         menu.append(item)
-        item = Gtk.ImageMenuItem(label=_("Quit"), image=Gtk.Image(icon_name="application-exit-symbolic", icon_size=Gtk.IconSize.MENU))
+        item = Gtk.ImageMenuItem(label=_("Quit"), image=Gtk.Image(icon_name="xsi-exit-symbolic", icon_size=Gtk.IconSize.MENU))
         item.connect('activate', lambda widget: self.main_window.destroy())
         key, mod = Gtk.accelerator_parse("<Control>Q")
         item.add_accelerator("activate", accel_group, key, mod, Gtk.AccelFlags.VISIBLE)
@@ -255,6 +256,29 @@ class MintBackup:
                     self.show_message(_("%s is not located in your home directory.") % filename)
         dialog.destroy()
 
+    def add_all_hidden_to_treeview(self, widget, treeview):
+        directory = self.home_directory
+        model = treeview.get_model()
+
+        existing_paths = {row[2] for row in model}
+
+        new_items = []
+        for item in os.listdir(directory):
+            if item.startswith('.'):
+                full_path = os.path.join(directory, item)
+                if full_path not in existing_paths:
+                    if os.path.isfile(full_path):
+                        new_items.append([item, self.file_icon, full_path])
+                    elif os.path.isdir(full_path):
+                        new_items.append([item, self.dir_icon, full_path])
+
+        for item in new_items:
+            model.append(item)
+    
+    def remove_all_from_treeview(self, button, treeview):
+        model = treeview.get_model()
+        model.clear()
+
     def remove_item_from_treeview(self, button, treeview):
         # Remove the item from the treeview
         model = treeview.get_model()
@@ -485,13 +509,13 @@ class MintBackup:
     def set_widgets_after_backup(self):
         if len(self.errors) > 0:
             self.builder.get_object("label_finished_status").set_markup(_("The following errors occurred:"))
-            self.builder.get_object("image_finished").set_from_icon_name("dialog-error-symbolic", Gtk.IconSize.DIALOG)
+            self.builder.get_object("image_finished").set_from_icon_name("xsi-dialog-error-symbolic", Gtk.IconSize.DIALOG)
             self.builder.get_object("treeview_backup_errors").set_model(self.errors)
             self.builder.get_object("win_errors").show_all()
         else:
             if not self.operating:
                 self.builder.get_object("label_finished_status").set_markup(_("The backup was aborted."))
-                self.builder.get_object("image_finished").set_from_icon_name("dialog-warning-symbolic", Gtk.IconSize.DIALOG)
+                self.builder.get_object("image_finished").set_from_icon_name("xsi-dialog-warning-symbolic", Gtk.IconSize.DIALOG)
             else:
                 self.builder.get_object("image_finished").set_from_icon_name("mintbackup-success-symbolic", Gtk.IconSize.DIALOG)
                 self.builder.get_object("label_finished_status").set_markup(_("Your files were successfully saved in %s.") % self.filename)
@@ -589,13 +613,13 @@ class MintBackup:
     def set_widgets_after_restore(self):
         if len(self.errors) > 0:
             self.builder.get_object("label_finished_status1").set_markup(_("The following errors occurred:"))
-            self.builder.get_object("image_finished1").set_from_icon_name("dialog-error-symbolic", Gtk.IconSize.DIALOG)
+            self.builder.get_object("image_finished1").set_from_icon_name("xsi-dialog-error-symbolic", Gtk.IconSize.DIALOG)
             self.builder.get_object("treeview_restore_errors").set_model(self.errors)
             self.builder.get_object("win_errors1").show_all()
         else:
             if not self.operating:
                 self.builder.get_object("label_finished_status1").set_markup(_("The restoration was aborted."))
-                self.builder.get_object("image_finished1").set_from_icon_name("dialog-warning-symbolic", Gtk.IconSize.DIALOG)
+                self.builder.get_object("image_finished1").set_from_icon_name("xsi-dialog-warning-symbolic", Gtk.IconSize.DIALOG)
             else:
                 self.builder.get_object("image_finished1").set_from_icon_name("mintbackup-success-symbolic", Gtk.IconSize.DIALOG)
                 self.builder.get_object("label_finished_status1").set_markup(_("Your files were successfully restored."))
